# Shift Attendance Sheet

Volunteer Timetable Management

Table of contents

- Changelog
  - 12.0.1.2.0 (2022-12-16)
- Bug Tracker
- Credits
  - Authors
  - Contributors
  - Maintainers

# Changelog

## 12.0.1.2.0 (2022-12-16)

Bugfixes

- Repair UI bug where there are two left-hand entries for changing shifts settings in the settings interface. (#488)

# Bug Tracker

Bugs are tracked on GitHub Issues. In case of trouble, please check there if your issue has already been reported. If you spotted it first, help us to smash it by providing a detailed and welcomed feedback.

Do not contact contributors directly about support or help with technical issues.

# Credits

## Authors

- Elouan Le Bars
- Coop IT Easy SC

## Contributors

- BEES coop - Cellule IT
- Coop IT Easy SC

## Maintainers

This module is part of the beescoop/Obeesdoo project on GitHub.

You are welcome to contribute.